==> wallace-platform-0.11.2.tar.gz: wallace-platform-0.11.2/README.md <==
Wallace
=======
[![Build Status](https://travis-ci.org/berkeley-cocosci/Wallace.svg?branch=master)](https://travis-ci.org/berkeley-cocosci/Wallace)
[![Coverage Status](https://coveralls.io/repos/github/berkeley-cocosci/Wallace/badge.svg?branch=master)](https://coveralls.io/github/berkeley-cocosci/Wallace?branch=master)
[![Code Climate](https://codeclimate.com/github/berkeley-cocosci/Wallace/badges/gpa.svg)](https://codeclimate.com/github/berkeley-cocosci/Wallace)
[![License](https://img.shields.io/github/license/berkeley-cocosci/Wallace.svg)](http://en.wikipedia.org/wiki/MIT_License)

<img src="portrait.jpg?raw=true" width="125" alt="Portrait of Alfred Russel Wallace">

Wallace is a platform for conducting research on experimental cultural evolution. Its namesake is Alfred Russel Wallace, a British naturalist and the oft-ignored codiscoverer of evolution by natural selection. You can use Wallace to create new experiments or to reproduce existing experiments.

Features
--------
- Runs experiments on experimental cultural evolution
- Coordinates participant recruitment using Mechanical Turk
- Demos of common experimental paradigms

Install
-------

To install Wallace, please see [Installing Wallace (for users)](docs/Installing-Wallace-(for-users).md).
For a development install of Wallace, please see [Developing Wallace (setup guide)](docs/Developing-Wallace-(setup-guide).md).

Documentation
-------------

Documentation is available in the [docs](docs) directory.

Contribute
----------
- Issue Tracker: http://github.com/berkeley-cocosci/Wallace/issues
- Source Code: http://github.com/berkeley-cocosci/Wallace

Support
-------
If you are having issues, please let us know.
We run a users group at https://groups.google.com/d/forum/wallace-users

License
-------
The project is licensed under the MIT license.

==> wallace-platform-0.12.2.tar.gz: wallace-platform-0.12.2/README.md <==
Wallace
=======
[![Build Status](https://travis-ci.org/berkeley-cocosci/Wallace.svg?branch=master)](https://travis-ci.org/berkeley-cocosci/Wallace)
[![Coverage Status](https://coveralls.io/repos/github/berkeley-cocosci/Wallace/badge.svg?branch=master)](https://coveralls.io/github/berkeley-cocosci/Wallace?branch=master)
[![Code Climate](https://codeclimate.com/github/berkeley-cocosci/Wallace/badges/gpa.svg)](https://codeclimate.com/github/berkeley-cocosci/Wallace)
[![License](https://img.shields.io/github/license/berkeley-cocosci/Wallace.svg)](http://en.wikipedia.org/wiki/MIT_License)

<img src="portrait.jpg?raw=true" width="125" alt="Portrait of Alfred Russel Wallace">

Wallace is a platform for conducting research on experimental cultural evolution. Its namesake is Alfred Russel Wallace, a British naturalist and the oft-ignored codiscoverer of evolution by natural selection. You can use Wallace to create new experiments or to reproduce existing experiments.

Features
--------
- Runs experiments on experimental cultural evolution
- Coordinates participant recruitment using Mechanical Turk
- Demos of common experimental paradigms

Install
-------
To install Wallace, see [Developing Wallace (setup guide)](http://wallace.readthedocs.io/en/latest/developing_wallace_setup_guide.html).

Documentation
-------------
Documentation is available on the [documentation website](http://wallace.readthedocs.io/).

Contribute
----------
- Issue Tracker: http://github.com/berkeley-cocosci/Wallace/issues
- Source Code: http://github.com/berkeley-cocosci/Wallace

Support
-------
If you are having issues, please let us know.
We run a users group at https://groups.google.com/d/forum/wallace-users

License
-------
The project is licensed under the MIT license.
